=========
Changelog
=========

Version 1.0.0
=============

- Stable release

Version 0.5.0
=============

- Updates & fixes

Version 0.4.0
=============

- Add generic search method

Version 0.3.0
=============

- Support `is_absent`, `below`, `above`

Version 0.2.1
=============

- Support Ingestion

Version 0.2.0
=============

- Initial Release.
